@@ -26,7 +26,6 @@ from datetime import datetime, timedelta
 from pathlib import Path
 
 from openstef.data_classes.prediction_job import PredictionJobDataClass
-
 from openstef.enums import MLModelType
 from openstef.pipeline.train_model import train_model_pipeline
 from openstef.tasks.utils.predictionjobloop import PredictionJobLoop
@@ -57,8 +56,10 @@ def train_model_task(
         check_old_model_age (bool): check if model is too young to be retrained
     """
     # Get the paths for storing model and reports from the config manager
-    trained_models_folder = Path(context.config.paths.trained_models_folder)
-    context.logger.debug(f"trained_models_folder: {trained_models_folder}")
+    mlflow_tracking_uri = context.config.paths.mlflow_tracking_uri
+    context.logger.debug(f"MLflow tracking uri: {mlflow_tracking_uri}")
+    artifact_folder = context.config.paths.artifact_folder
+    context.logger.debug(f"Artifact folder: {artifact_folder}")
 
     context.perf_meter.checkpoint("Added metadata to PredictionJob")
 
@@ -80,13 +81,24 @@ def train_model_task(
     context.perf_meter.checkpoint("Retrieved timeseries input")
 
     # Excecute the model training pipeline
-    train_model_pipeline(
+    data_sets = train_model_pipeline(
         pj,
         input_data,
         check_old_model_age=check_old_model_age,
-        trained_models_folder=trained_models_folder,
+        mlflow_tracking_uri=mlflow_tracking_uri,
+        artifact_folder=artifact_folder,
     )
 
+    if pj.save_train_forecasts:
+        if data_sets is None:
+            raise RuntimeError("Forecasts were not retrieved")
+        if not hasattr(context.database, "write_train_forecasts"):
+            raise RuntimeError(
+                "Database connector does dot support 'write_train_forecasts' while "
+                "'save_train_forecasts option was activated.'"
+            )
+        context.database.write_train_forecasts(pj, data_sets)
+
     context.perf_meter.checkpoint("Model trained")
 
 
@@ -94,7 +106,8 @@ def main(model_type=None, config=None, database=None):
 
     if database is None or config is None:
         raise RuntimeError(
-            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+            "Please specifiy a configmanager and/or database connection object. These"
+            " can be found in the openstef-dbc package."
         )
 
     if model_type is None:
